package
Version:
v1.0.4
Opens a new window with list of versions in this module.
Published: Jun 8, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Postgres struct {
DB *sql.DB
}
Postgres holds the PostgreSQL connection.
NewPostgres creates a new PostgreSQL connection from config.
Close closes the database connection.
Redis holds the Redis client.
NewRedis creates a new Redis client from config.
Close closes the Redis connection.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.